Package 'hydflood'
| Title: |
Flood Extents and Duration along the Rivers Elbe and Rhine |
| Description: |
Raster based flood modelling internally using 'hyd1d', an
R package to interpolate 1d water level and gauging data. The
package computes flood extent and duration through strategies
originally developed for 'INFORM', an 'ArcGIS'-based
hydro-ecological modelling framework. It does not provide a
full, physical hydraulic modelling algorithm, but a simplified,
near real time 'GIS' approach for flood extent and duration
modelling. Computationally demanding annual flood durations
have been computed already and data products were published by
Weber (2022) <doi:10.1594/PANGAEA.948042>. |
| Authors: |
Arnd Weber [aut, cre] (ORCID: <https://orcid.org/0000-0002-5973-2770>),
Stephan Rosenzweig [ctb],
Benjamin Eberhardt [ctb] |
| Maintainer: |
Arnd Weber <[email protected]> |
| License: |
GPL-2 |
| Version: |
0.5.10 |
| Built: |
2026-06-06 05:34:30 UTC |
| Source: |
https://github.com/bafg-bund/hydflood |
Help Index